function vardec = mse(F, B, V, G, horz)

% mse.m computes the mean squared error forecast for the following
% structural model at horizons specified in horz:
% model:
% s(t) = F*s(t-1) + B*u(t) where u(t) N(0,V)
% y(t) = G*s(t)
% return:
% vardec = no of states by max(horz)+1, last col of vardec is unconditional
% variance

k = max(horz);
[nobs ns] = size(G);
vardec = zeros(nobs,k+1); 
FF = eye(ns);
Q = B*V*B';
sigxk = zeros(size(Q));

% for horz 1 to k
for i = 1:k
    sigxk = sigxk + FF*Q*FF';       % Sigma xk
    sigyk = G*sigxk*G';
    vardec(:,i) = diag(sigyk);      % store var of forecast error at horz k
    FF = FF*F;  
end

% for unconditional variance
Gzero = Q;
alpha0 = F;
gamma0 = Gzero;
diff = 5;
ijk=0;
while diff > 1e-15;
  alpha1 = alpha0*alpha0;
  gamma1 = gamma0+alpha0*gamma0*alpha0';
  diff = max(max(abs(gamma1-gamma0)));
  gamma0 = gamma1;
  alpha0 = alpha1;
  ijk = ijk+1;
   if ijk>500;
     disp('Warning: problem finding variance of VAR')
   end;   
end;
gamma0 = G*gamma0*G';
vardec(:,i+1) = diag(gamma0);           % store unconditional variance

% return only selected horizons
vardec = vardec(:,[horz k+1]); 





