function [ GAM0, GAM1,C, PSI, PPI, A1, B1, A2,B2,H, modinfo] = modelJPshortH(Theta)

% Functions called:
%             
%==========================================================================

%%  SETTING  PARAMETERS:
beta        = 0.99;
lambda       = Theta(1);
sigma       = Theta(2);
alpha      = Theta(3);
kappa     = Theta(4);
rho     = Theta(5);
phipi         = Theta(6);
phiy          = Theta(7);
rho1     = Theta(8);
rho2     = Theta(9);
rho3     =0;


%********************************************************************
%*      matrices of canonical system
%********************************************************************/

%* equation indices **/
eq.IS       = 1;   % 
eq.PC      = 2;   % 
eq.r      = 3;   % 
eq.vy      = 4;   % 
eq.vpi      = 5;   % i
eq.vr      = 6;   % i

eq.EY      = 7;   % i
eq.EPI       = 8;   %



%* variable indices **/
v.y         = 1;    %
v.pi         = 2;    %
v.r         = 3;    %
v.vy       = 4;    %
v.vpi       = 5;    %
v.vr       = 6;    %
v.EY      = 7;   % i
v.EPI       = 8;   %


%* shock indices **/
e.y     	= 1;    % monetary policy
e.pi         = 2;    % preference
e.r         = 3;    % technology



%* expectation error indices **/
n.EY        = 1;  % E consumption
n.EPI      = 2;  % E home inflation

% observation equation
hh.y         = 1;
hh.pi      	= 2;
hh.r       = 3;


%* summary **/
neq  = length(fieldnames(eq));
neps = length(fieldnames(e));
neta = length(fieldnames(n));
modinfo.eq = eq;
modinfo.v  = v;
modinfo.e  = e;
modinfo.n  = n;
modinfo.h  = hh;

%* initialize matrices **/
GAM0 = zeros(neq,neq);
GAM1 = zeros(neq,neq);
   C = zeros(neq,1);
 PSI = zeros(neq,neps);
 PPI = zeros(neq,neta);
   H = zeros(length(fieldnames(hh)),neq-neta);


%% equations
H(hh.y,v.y) = 1;
H(hh.pi,v.pi) = 1;
H(hh.r,v.r) = 1;



% GAM0 y(t) = GAM1 y(t-1) + C + PSI z(t) + PPI eta(t) 
%*********************************************************
%**      1. IS Curve
%*********************************************************/
GAM0(eq.IS,v.y)         =  1;
GAM0(eq.IS,v.EY)         =  -lambda;
GAM1(eq.IS,v.y)        = (1-lambda);
GAM0(eq.IS,v.r)         =  1/sigma;
GAM0(eq.IS,v.EPI)      = -1/sigma;
GAM0(eq.IS,v.vy)      = -1;



%*********************************************************
%*      2. Phillips Curve
%**********************************************************/
GAM0(eq.PC,v.pi)         =  1;
GAM0(eq.PC,v.EPI)        =  -beta/(1+(alpha*beta));
GAM1(eq.PC,v.pi)        = alpha/(1+(alpha*beta));
GAM0(eq.PC,v.y)        =  -kappa;
GAM0(eq.PC,v.vpi)      = -1;

%*********************************************************
%**      3. Policy Rule
%**********************************************************/

GAM1(eq.r,v.r)       =  rho;
GAM0(eq.r,v.pi)     = (1-rho)*phipi*-1;
GAM0(eq.r,v.y)     =  (1-rho)*phiy*-1;
GAM0(eq.r,v.vr)     =  -1;
GAM0(eq.r,v.r)     =  1;



 

%*********************************************************
%**      Exogenous processes
%**********************************************************/
% 
GAM0(eq.vy,v.vy)    = 1;
GAM1(eq.vy,v.vy)    = rho1;
 PSI(eq.vy,e.y)       = 1;
%
GAM0(eq.vpi,v.vpi)    = 1;
GAM1(eq.vpi,v.vpi)    = rho2;
 PSI(eq.vpi,e.pi)       = 1;
% 
PSI(eq.vr,e.r)       = 1;
GAM0(eq.vr,v.vr)    = 1;
GAM1(eq.vr,v.vr)    = rho3;

 
%*********************************************************
%**      Expectation errors
%**********************************************************/
% 
GAM0(eq.EY,v.y)       = 1;
GAM1(eq.EY,v.EY)      = 1;
 PPI(eq.EY,n.EY)      = 1;
 % 18. 
GAM0(eq.EPI,v.pi)       = 1;
GAM1(eq.EPI,v.EPI)      = 1;
 PPI(eq.EPI,n.EPI)      = 1;
 

% Rearrange matrices into forward and backward looking block (see eq30
% Farmer et al)
% GAM0 = [A1 A2]' where A1=(neq-neta)Xneq, A2=netaXneq 
% GAM1 = [B1 B2]' where B1=(neq-neta)Xneq, B2=netaXneq  

A1=GAM0(1:neq-neta,:);
B1=GAM1(1:neq-neta,:);
A2=GAM0(neq-neta+1:end,:);
B2=GAM1(neq-neta+1:end,:);
