function lnprior = priorln(para, pshape, p1, p2)

% priorln.m
% This function computes the log of the joint prior distribution for the 
% parameters (para) with distributions given by (pshape, p1, p2) 
%The code comes with no performance guarantees.
% However, if you find this code useful then please cite the paper.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Orginal author: Frank Schorfheide 
% July 2005: transfered from Gauss to matlab by Philip Liu
% July 2005: modified by Philip Liu
%
%==========================================================================
% Input:
%       pshape: 0 is point mass, both para and p2 are ignored
%               1 is BETA(mean,stdd)
%               2 is GAMMA(mean,stdd)
%               3 is NORMAL(mean,stdd)
%               4 is INVGAMMA(s^2,nu)
%               5 is UNIFORM [p3,p4]
%       p1 = mean   
%       p2 = std
% Returns:
%       lnprior = log of the prior density
% Calls: 
%       lpdfbeta: log of the beta pdf
%       lpdfgam: log of the gamma pdf
%       lpdnorm: log of the normal pdf
%       lpdfig1: log of the inverser gamma pdf
%==========================================================================
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


lnprior = 0;
nprio = length(pshape);

i = 1;
while i <=  nprio;
    a = 0;
    b = 0;

    switch pshape(i)
        case 1;     %  BETA Prior
        a = (1-p1(i))*p1(i)^2/p2(i)^2 - p1(i);
        b = a*(1/p1(i) - 1);
        lnprior = lnprior + lpdfbeta(para(i),a,b);

        case 2;     % GAMMA PRIOR
        %        a = p1(i)^2/p2(i)^2;
        %        b = p2(i)^2/p1(i);
        % %      a = p1(i)/b;
        %      lnprior = lnprior + log(gampdf(para(i),a,b));
        b = p2(i)^2/p1(i);
        a = p1(i)/b;
        lnprior = lnprior + lpdfgam(para(i),a,b);
        case 3;     % GAUSSIAN PRIOR
        lnprior = lnprior + lpdfnorm(para(i),p1(i),p2(i));

        case 4;     % INVGAMMA PRIOR
        %      a = p1(i)^2/p2(i)^2 + 2;
        %      b = p1(i)*(a-1);
        %      lnprior = lnprior + lpdfig(para(i),p1(i),p2(i));
        lnprior = lnprior + lpdfig1(para(i),p1(i),p2(i));

        case 5;     % multivariate beta
        lnprior = lnprior + eval_d([p1(i);p2(i)],para(i));
        
        case 6;     % UNIFORM PRIOR
        lnprior = lnprior + log(1/(p2(i)-p1(i)));
        
    end;
    i = i+1;
    
end;