function [alpha,beta,gam,lmbd]=canon(y,x,z,r)
%  mww, 6/7/2004 Translated July 2013
%    This procedure computes the r largest canonical correlations between y
%    and x after partialling out z
%    
%    The regression model has the form
%    
%    Y = X*Gam + e
%    
%    where Y is Nxp
%          X is Nxk Gam is kxp
%          
%          Rank(Gam) = r
%          
%          Gam is factored as Gam=Alpha*Beta' where Alhpa is kxr and Beta
%          is pxr
%          
%          Note, an alternative way to write this is 
%          
%          y(i) = Beta*alpha'x(i) + e(i)
%          

%step 1: Partial out z
n=rows(x);
if rows(z) == n;
 b=z\y;
 y=y-z*b;
 b=z\x;%x/z;
 x=x-z*b;
end

%step 2 construct moment matrices
sxxi=invpd(x'*x/n);
syyi=invpd(y'*y/n);
cxxi=chol(sxxi);
sxy=(x'*y/n);
tmp=cxxi*sxy;
tmp=tmp*syyi*tmp';
[vax,vex]=eighv(tmp);
lmbd=vax;
alpha=vex(:,1:r);
alpha=cxxi'*alpha;
beta=sxy'*alpha;
gam=alpha*beta';