function [beta1 p01 f PROBLEM] = flike(F, Q, beta0, p0, yi, H, muhat,r)

% the function fike computes the kalman filter update for each regime
% input:  y(t)    = H*beta(t) + e(t) where e(t)~N(0,r)
%         beta(t) = muhat + F*beta(t-1) + vep(t) where vep(t)~N(0,Q)
% output: beta1   = updated state
%         p01     = updated var-cov of state
%         f       = conditional likelihood

ny   = size(H,1);
PROBLEM = 0;
% forecasting
beta = muhat + beta0*F';
p10  = F*p0*F' + Q;
yhat = (H*(beta)')';

eta  = yi - yhat - muhat;
feta = (H*p10*H') + r;
if rcond(feta)<=1e-10;
    f = -inf;
    beta1 = 0;
    p01    = 0;
    PROBLEM = 1;
    return;
else
    fetainv = inv(feta);
end

% updating
K     = (p10*H')*fetainv;
beta1 = (beta'+K*eta')';
p01   = p10-K*(H*p10);

% calculate likelihood
 f     = -0.5*ny*log(2*pi) + 0.5*log(det(fetainv)) - 0.5*eta*fetainv*eta';
 f     = exp(f);
%f = fs(eta,feta);

% if 1-isreal(f) || f>=0 || isnan(f);
%     f = -inf;
%     beta1 = 0;
%     p01    = 0;
%     PROBLEM = 1;
%     return;
% end;
% 













