function [x0T,xtT,vtT]=kfks(H,phi,omega,betamat,data)
% Function to implement Kalman smoother in order to extract smoothed
% innovations (method due to de Jong, implementation from Pollock (2002))
% rxh 19.09.08
% Model is:
% y(t) = H*x(t) + eta(t)
% x(t) = phi*x(t-1) + psi*v(t)
% E(eta*eta')=omega
% E(v*v')=psi

[nobs,ns]=size(H);
[T,junk0]=size(data); % Data enters as T by nobs (ie in columns)
data=data'; % Transform to rows to make algebra easier
psi = betamat * betamat';
betamatpinv = (betamat'*betamat)\betamat';

x=zeros(ns,T); 
P=zeros(ns,ns,T);
e=zeros(nobs,T);
F=zeros(nobs,nobs,T);
K=zeros(ns,nobs,T);
lambda=P;
q=zeros(ns,T);
vtT=zeros(size(betamatpinv,1),T);
xtT=zeros(ns,T);

% Kalman filter
% P0=asympt_variance(phi,psi^0.5); % Initialise P0
P0 = 0.0001*eye(ns);
Pold=P0;
xold=zeros(ns,1);

[vy, vx] = find(H ~= 0);

for i = 1 : size(vx,1);
    xold(vx,1) = data(1,vy);
end;

for t=1:T 
    xup=phi*xold;
    Pup=phi*Pold*phi'+psi;
    e(:,t)=data(:,t)-H*xup;
    F(:,:,t)=H*Pup*H'+omega;
    K(:,:,t)=(Pup*H')/F(:,:,t);
    x(:,t)=xup+K(:,:,t)*e(:,t);
    xold=x(:,t);
    P(:,:,t)=(eye(ns)-K(:,:,t)*H)*Pup;
    Pold=P(:,:,t);
    lambda(:,:,t)=(eye(ns)-K(:,:,t)*H)*phi;
end

% Smoother
% Backward recursion to construct working variable
q(:,T)=((phi'*H')/F(:,:,T))*e(:,T); % Initialise q process
for t=T-1:-1:1
    q(:,t)=((phi'*H')/F(:,:,t))*e(:,t)+lambda(:,:,t+1)'*q(:,t+1);
end
% Forward recursion to extract states & shocks
x0T=P0*q(:,1);
xsold=x0T;
q=[q zeros(ns,1)]; % Expand q vector
for t=1:T
   xtT(:,t)=x(:,t)+P(:,:,t)*q(:,t+1);
   vtT(:,t)=betamatpinv*(xtT(:,t)-phi*xsold);
   xsold=xtT(:,t);
end

% Transpose to export states and shocks as time series in columns
xtT=xtT';
vtT=vtT';

