%% Housekeeping
close all
clear
clc
%% Load Simulate Data
load PolicyUncertaintySimRes.mat
NoSim=size(SimData,3);
T=size(SimData,2);
dy=size(SimData,1);
%% VAR
L=2;
HORZ=19;
shockcolumn=1;
VAR.p=L; % Number of Lags
VAR.irhor=HORZ; % Impulse Response Horizon
fsave=zeros(HORZ,dy-1,NoSim);
temp3=zeros(HORZ,dy-1,NoSim);
MeasurementError=0:5;
DistCholVAR=zeros(HORZ,dy-1,3,length(MeasurementError));
DistProxyVAR=zeros(HORZ,dy-1,3,length(MeasurementError));
CholVARIrfBias=zeros(HORZ,dy-1,length(MeasurementError));
ProxyVARIrfBias=zeros(HORZ,dy-1,length(MeasurementError));

for j = 1 : length(MeasurementError);
    
    for i = 1 : NoSim
        datamat=SimData(1:dy,:,i)';
        M=datamat(:,1)+MeasurementError(j)*randn(T,1);
        %| Choleski VAR
        Y1=[M datamat(:,3:end)];
        fsaveA=runcholvarolsK(Y1,L,HORZ,shockcolumn);
        fsave(:,:,i)=fsaveA./fsaveA(1,1);
        
        %| Proxy VAR
        Y2=datamat(:,2:end);
        VAR.vars=Y2; %order the first variable in data is where the shock identified
        VAR.proxies = M; %proxy variable
        
        VAR01=VAR;
        VAR01=doProxySVAR_single(VAR01);
        temp=VAR01.irs*-1;
        temp3(:,:,i)=temp;                              %produced irfs are for a negative 1 unit shock
    end
    
    DistCholVAR(:,:,:,j)=quantile(fsave,[0.5 0.05 0.95],3);
    DistProxyVAR(:,:,:,j)=quantile(temp3,[0.5 0.05 0.95],3);
    
    CholVARIrfBias(:,:,j)=DistCholVAR(:,:,1,j)-(DsgeIrfs(:,1:HORZ)./DsgeIrfs(1,1))';
    ProxyVARIrfBias(:,:,j)=DistProxyVAR(:,:,1,j)-(DsgeIrfs(:,1:HORZ)./DsgeIrfs(1,1))';
end
%% Plots
varnames={'Uncertainty','Y','\pi','R'};
IndexProxy=1:3;
IndexChol=4:6;
xxx=1:HORZ;
figure
orient landscape
for i = 1:3
    subplot(2,3,IndexProxy(i))
    plotx1(xxx,squeeze(DistProxyVAR(:,i+1,:)))
    hold on
    plot(xxx,DsgeIrfs(i+1,1:HORZ)./DsgeIrfs(1,1),'.','LineWidth',1.5)
    hold off
    axis tight
    title(varnames{i+1})
    if i==1
        ylabel('Proxy VAR')
    end
    
    subplot(2,3,IndexChol(i))
    plotx1(xxx,squeeze(DistCholVAR(:,i+1,:)))
    hold on
    plot(xxx,DsgeIrfs(i+1,1:HORZ)./DsgeIrfs(1,1),'.','LineWidth',1.5)
    hold off
    axis tight
    if i==1
        ylabel('Recursive VAR')
    end
    if i==3
        legend('90% Error Band','Median IRF','DSGE IRF')
    end
end
hgsave('../figure_files/Figure1PolicyUncertainty')


figure
orient landscape
for i = 1:3
    TermA= min(min(squeeze(CholVARIrfBias(:,i+1,:))));
    TermB= min(min(squeeze(ProxyVARIrfBias(:,i+1,:))));
    TermC=max(max(squeeze(CholVARIrfBias(:,i+1,:))));
    TermD=max(max(squeeze(ProxyVARIrfBias(:,i+1,:))));
    subplot(2,3,IndexProxy(i))
    mesh(MeasurementError,xxx,squeeze(ProxyVARIrfBias(:,i+1,:)))
    axis([0 5 0 18 min(TermA,TermB) max(TermC,TermD)])
    title(varnames{i+1})
    ylabel('Horizon')
    xlabel('\sigma_v/\sigma_{\sigma_r}')
    zlabel('Proxy VAR')
    
    subplot(2,3,IndexChol(i))
    mesh(MeasurementError,xxx,squeeze(CholVARIrfBias(:,i+1,:)))
    axis([0 5 0 18 min(TermA,TermB) max(TermC,TermD)])
    title(varnames{i+1})
    ylabel('Horizon')
    xlabel('\sigma_v/\sigma_{\sigma_r}')
    zlabel('Recursive VAR')
    
end
hgsave('../figure_files/Figure2PolicyUncertainty')
